@@ -11,7 +11,7 @@
 
 from __future__ import absolute_import
 
-__version__ = '0.1.9'
+__version__ = '0.1.11'
 
 import hashlib
 import random
@@ -83,7 +83,7 @@ class SeaSurf(object):
         
         <form method="POST">
         ...
-        <input type="hidden" name="_csrf_token" value="{{ csrf_token }}">
+        <input type="hidden" name="_csrf_token" value="{{ csrf_token() }}">
         </form>
     
     This will assign a token to both the session cookie and the rendered HTML 
@@ -191,7 +191,7 @@ class SeaSurf(object):
             if request_csrf_token == '':
                 # As per the Django middleware, this makes AJAX easier and 
                 # PUT and DELETE possible
-                request_csrf_token = request.headers.get('HTTP_X_CSRFTOKEN', '')
+                request_csrf_token = request.headers.get('X-CSRFToken', '')
             
             if not _constant_time_compare(request_csrf_token, csrf_token):
                 error = (REASON_BAD_TOKEN, request.path)
